@@ -1,3 +1,123 @@
+
+#' Independent vertex sets
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `maximal.independent.vertex.sets()` was renamed to `maximal_ivs()` to create a more
+#' consistent API.
+#' @inheritParams maximal_ivs
+#' @keywords internal
+#' @export
+maximal.independent.vertex.sets <- function(graph) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "maximal.independent.vertex.sets()", "maximal_ivs()")
+  maximal_ivs(graph = graph)
+} # nocov end
+
+#' Functions to find cliques, i.e. complete subgraphs in a graph
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `maximal.cliques.count()` was renamed to `count_max_cliques()` to create a more
+#' consistent API.
+#' @inheritParams count_max_cliques
+#' @keywords internal
+#' @export
+maximal.cliques.count <- function(graph, min = NULL, max = NULL, subset = NULL) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "maximal.cliques.count()", "count_max_cliques()")
+  count_max_cliques(graph = graph, min = min, max = max, subset = subset)
+} # nocov end
+
+#' Functions to find cliques, i.e. complete subgraphs in a graph
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `maximal.cliques()` was renamed to `max_cliques()` to create a more
+#' consistent API.
+#' @inheritParams max_cliques
+#' @keywords internal
+#' @export
+maximal.cliques <- function(graph, min = NULL, max = NULL, subset = NULL, file = NULL) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "maximal.cliques()", "max_cliques()")
+  max_cliques(graph = graph, min = min, max = max, subset = subset, file = file)
+} # nocov end
+
+#' Independent vertex sets
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `largest.independent.vertex.sets()` was renamed to `largest_ivs()` to create a more
+#' consistent API.
+#' @inheritParams largest_ivs
+#' @keywords internal
+#' @export
+largest.independent.vertex.sets <- function(graph) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "largest.independent.vertex.sets()", "largest_ivs()")
+  largest_ivs(graph = graph)
+} # nocov end
+
+#' Functions to find cliques, i.e. complete subgraphs in a graph
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `largest.cliques()` was renamed to `largest_cliques()` to create a more
+#' consistent API.
+#' @inheritParams largest_cliques
+#' @keywords internal
+#' @export
+largest.cliques <- function(graph) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "largest.cliques()", "largest_cliques()")
+  largest_cliques(graph = graph)
+} # nocov end
+
+#' Independent vertex sets
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `independent.vertex.sets()` was renamed to `ivs()` to create a more
+#' consistent API.
+#' @inheritParams ivs
+#' @keywords internal
+#' @export
+independent.vertex.sets <- function(graph, min = NULL, max = NULL) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "independent.vertex.sets()", "ivs()")
+  ivs(graph = graph, min = min, max = max)
+} # nocov end
+
+#' Independent vertex sets
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `independence.number()` was renamed to `ivs_size()` to create a more
+#' consistent API.
+#' @inheritParams ivs_size
+#' @keywords internal
+#' @export
+independence.number <- function(graph) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "independence.number()", "ivs_size()")
+  ivs_size(graph = graph)
+} # nocov end
+
+#' Functions to find cliques, i.e. complete subgraphs in a graph
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `clique.number()` was renamed to `clique_num()` to create a more
+#' consistent API.
+#' @inheritParams clique_num
+#' @keywords internal
+#' @export
+clique.number <- function(graph) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "clique.number()", "clique_num()")
+  clique_num(graph = graph)
+} # nocov end
 #   IGraph R package
 #   Copyright (C) 2006-2012  Gabor Csardi <csardi.gabor@gmail.com>
 #   334 Harvard street, Cambridge, MA 02139 USA
@@ -44,9 +164,7 @@
 #' `clique_size_counts()` returns a numeric vector representing a histogram
 #' of clique sizes, between the given minimum and maximum clique size.
 #'
-#' @aliases cliques largest_cliques maximal.cliques maximal.cliques.count
-#' clique.number clique_num largest.cliques count_max_cliques max_cliques
-#' clique_size_counts
+#' @inheritParams weighted_cliques
 #' @param graph The input graph, directed graphs will be considered as
 #'   undirected ones, multiple edges and loops are ignored.
 #' @param min Numeric constant, lower limit on the size of the cliques to find.
@@ -70,7 +188,6 @@
 #'
 #' @author Tamas Nepusz \email{ntamas@@gmail.com} and Gabor Csardi
 #' \email{csardi.gabor@@gmail.com}
-#' @seealso [ivs()]
 #' @references For maximal cliques the following algorithm is implemented:
 #' David Eppstein, Maarten Loffler, Darren Strash: Listing All Maximal Cliques
 #' in Sparse Graphs in Near-optimal Time.  <https://arxiv.org/abs/1006.5440>
@@ -90,7 +207,7 @@
 #' max_cliques(g)
 cliques <- cliques_impl
 
-#' @family cliques
+#' @rdname cliques
 #' @export
 largest_cliques <- largest_cliques_impl
 
@@ -105,12 +222,9 @@ largest_cliques <- largest_cliques_impl
 #'   it exists, then it will be overwritten.) Each clique will be a separate line
 #'   in the file, given with the numeric ids of its vertices, separated by
 #'   whitespace.
-#' @family cliques
 #' @export
 max_cliques <- function(graph, min = NULL, max = NULL, subset = NULL, file = NULL) {
-  if (!is_igraph(graph)) {
-    stop("Not a graph object")
-  }
+  ensure_igraph(graph)
 
   if (is.null(min)) {
     min <- 0
@@ -120,7 +234,7 @@ max_cliques <- function(graph, min = NULL, max = NULL, subset = NULL, file = NUL
   }
 
   if (!is.null(subset)) {
-    subset <- as.integer(as.igraph.vs(graph, subset) - 1)
+    subset <- as.numeric(as_igraph_vs(graph, subset) - 1)
   }
 
   if (!is.null(file)) {
@@ -159,14 +273,12 @@ max_cliques <- function(graph, min = NULL, max = NULL, subset = NULL, file = NUL
   }
 }
 
-#' @family cliques
+#' @rdname cliques
 #' @export
 count_max_cliques <- function(graph, min = NULL, max = NULL,
                               subset = NULL) {
   # Argument checks
-  if (!is_igraph(graph)) {
-    stop("Not a graph object")
-  }
+  ensure_igraph(graph)
 
   if (is.null(min)) {
     min <- 0
@@ -174,11 +286,11 @@ count_max_cliques <- function(graph, min = NULL, max = NULL,
   if (is.null(max)) {
     max <- 0
   }
-  min <- as.integer(min)
-  max <- as.integer(max)
+  min <- as.numeric(min)
+  max <- as.numeric(max)
 
   if (!is.null(subset)) {
-    subset <- as.integer(as.igraph.vs(graph, subset) - 1)
+    subset <- as.numeric(as_igraph_vs(graph, subset) - 1)
   }
 
   on.exit(.Call(R_igraph_finalizer))
@@ -188,18 +300,18 @@ count_max_cliques <- function(graph, min = NULL, max = NULL,
   res
 }
 
-#' @family cliques
+#' @rdname cliques
 #' @export
 clique_num <- clique_number_impl
 
 
-#' Functions to find weighted cliques, i.e. weighted complete subgraphs in a graph
+#' Functions to find weighted cliques, i.e. vertex-weighted complete subgraphs in a graph
 #'
 #' These functions find all, the largest or all the maximal weighted cliques in
 #' an undirected graph. The weight of a clique is the sum of the weights of its
-#' edges.
+#' vertices.
 #'
-#' `weighted_cliques()` find all complete subgraphs in the input graph,
+#' `weighted_cliques()` finds all complete subgraphs in the input graph,
 #' obeying the weight limitations given in the `min` and `max`
 #' arguments.
 #'
@@ -207,17 +319,8 @@ clique_num <- clique_number_impl
 #' input graph. A clique is largest if there is no other clique whose total
 #' weight is larger than the weight of this clique.
 #'
-#' `max_weighted_cliques` finds all maximal weighted cliques in the input graph.
-#' A weighted clique is maximal if it cannot be extended to a clique with larger
-#' total weight. The largest weighted cliques are always maximal, but a maximal
-#' weighted clique is not necessarily the largest.
-#'
-#' `count_max_weighted_cliques` counts the maximal weighted cliques.
-#'
 #' `weighted_clique_num()` calculates the weight of the largest weighted clique(s).
 #'
-#' @aliases weighted_cliques largest_weighted_cliques max_weighted_cliques
-#' count_max_weighted_cliques weighted_clique_num
 #' @param graph The input graph, directed graphs will be considered as
 #'   undirected ones, multiple edges and loops are ignored.
 #' @param min.weight Numeric constant, lower limit on the weight of the cliques to find.
@@ -235,12 +338,10 @@ clique_num <- clique_number_impl
 #'   list containing numeric vectors of vertex IDs. Each list element is a weighted
 #'   clique, i.e. a vertex sequence of class [`igraph.vs()`][V].
 #'
-#'   `weighted_clique_num()` and `count_max_weighted_cliques` return an integer
-#'   scalar.
+#'   `weighted_clique_num()` returns an integer scalar.
 #'
 #' @author Tamas Nepusz \email{ntamas@@gmail.com} and Gabor Csardi
 #' \email{csardi.gabor@@gmail.com}
-#' @seealso [ivs()]
 #' @family cliques
 #' @export
 #' @keywords graphs
@@ -255,8 +356,10 @@ clique_num <- clique_number_impl
 #' weighted_clique_num(g)
 weighted_cliques <- weighted_cliques_impl
 #' @export
+#' @rdname cliques
 largest_weighted_cliques <- largest_weighted_cliques_impl
 #' @export
+#' @rdname cliques
 weighted_clique_num <- weighted_clique_number_impl
 
 #' Independent vertex sets
@@ -278,15 +381,12 @@ weighted_clique_num <- weighted_clique_number_impl
 #' extended to a larger independent vertex set. The largest independent vertex
 #' sets are maximal, but the opposite is not always true.
 #'
-#' `independece.number` calculate the size of the largest independent
+#' `ivs_size()` calculate the size of the largest independent
 #' vertex set(s).
 #'
 #' These functions use the algorithm described by Tsukiyama et al., see
 #' reference below.
 #'
-#' @aliases independent.vertex.sets largest.independent.vertex.sets
-#' maximal.independent.vertex.sets independence.number ivs_size ivs
-#' largest_ivs maximal_ivs
 #' @param graph The input graph, directed graphs are considered as undirected,
 #'   loop edges and multiple edges are ignored.
 #' @param min Numeric constant, limit for the minimum size of the independent
@@ -303,7 +403,6 @@ weighted_clique_num <- weighted_clique_number_impl
 #' Graph Library by Keith Briggs (<http://keithbriggs.info/>) and Gabor
 #' Csardi \email{csardi.gabor@@gmail.com} wrote the R interface and this manual
 #' page.
-#' @seealso [cliques()]
 #' @references S. Tsukiyama, M. Ide, H. Ariyoshi and I. Shirawaka. A new
 #' algorithm for generating all the maximal independent sets. *SIAM J
 #' Computing*, 6:505--517, 1977.
@@ -325,9 +424,7 @@ weighted_clique_num <- weighted_clique_number_impl
 #'
 #' length(maximal_ivs(g))
 ivs <- function(graph, min = NULL, max = NULL) {
-  if (!is_igraph(graph)) {
-    stop("Not a graph object")
-  }
+  ensure_igraph(graph)
 
   if (is.null(min)) {
     min <- 0
@@ -351,12 +448,10 @@ ivs <- function(graph, min = NULL, max = NULL) {
   res
 }
 
-#' @family cliques
+#' @rdname ivs
 #' @export
 largest_ivs <- function(graph) {
-  if (!is_igraph(graph)) {
-    stop("Not a graph object")
-  }
+  ensure_igraph(graph)
 
   on.exit(.Call(R_igraph_finalizer))
   res <- .Call(R_igraph_largest_independent_vertex_sets, graph)
@@ -369,12 +464,10 @@ largest_ivs <- function(graph) {
   res
 }
 
-#' @family cliques
+#' @rdname ivs
 #' @export
 maximal_ivs <- function(graph) {
-  if (!is_igraph(graph)) {
-    stop("Not a graph object")
-  }
+  ensure_igraph(graph)
 
   on.exit(.Call(R_igraph_finalizer))
   res <- .Call(R_igraph_maximal_independent_vertex_sets, graph)
@@ -387,23 +480,21 @@ maximal_ivs <- function(graph) {
   res
 }
 
-#' @family cliques
+#' @rdname ivs
 #' @export
 ivs_size <- function(graph) {
-  if (!is_igraph(graph)) {
-    stop("Not a graph object")
-  }
+  ensure_igraph(graph)
 
   on.exit(.Call(R_igraph_finalizer))
   .Call(R_igraph_independence_number, graph)
 }
 
-#' @family cliques
+#' @rdname cliques
 #' @export
-clique_size_counts <- function(graph, min = 0, max = 0, maximal = FALSE, ...) {
+clique_size_counts <- function(graph, min = 0, max = 0, maximal = FALSE) {
   if (maximal) {
-    maximal_cliques_hist_impl(graph, min, max, ...)
+    maximal_cliques_hist_impl(graph, min, max)
   } else {
-    clique_size_hist_impl(graph, min, max, ...)
+    clique_size_hist_impl(graph, min, max)
   }
 }
