@@ -1,6 +1,6 @@
 test_that("make_bipartite_graph works", {
   I <- matrix(sample(0:1, 35, replace = TRUE, prob = c(3, 1)), ncol = 5)
-  g <- graph_from_incidence_matrix(I)
+  g <- graph_from_biadjacency_matrix(I)
 
   edges <- unlist(sapply(seq_len(nrow(I)), function(x) {
     w <- which(I[x, ] != 0) + nrow(I)
@@ -11,7 +11,7 @@ test_that("make_bipartite_graph works", {
     }
   }))
   g2 <- make_bipartite_graph(seq_len(nrow(I) + ncol(I)) > nrow(I), edges)
-  I2 <- as_incidence_matrix(g2)
+  I2 <- as_biadjacency_matrix(g2)
 
   expect_that(I2, is_equivalent_to(I))
 })
