@@ -1,5 +1,5 @@
 test_that("transitivity works", {
-  set.seed(42)
+  withr::local_seed(42)
   g <- sample_gnp(100, p = 10 / 100)
 
   t1 <- transitivity(g, type = "global")
@@ -22,7 +22,7 @@ test_that("transitivity works", {
 })
 
 test_that("no integer overflow", {
-  set.seed(42)
+  withr::local_seed(42)
   g <- make_star(80000, mode = "undirected") + edges(sample(2:1000), 100)
   mtr <- min(transitivity(g, type = "local"), na.rm = TRUE)
   expect_true(mtr > 0)
